@@ -160,14 +160,21 @@ class ConfusionMatrixWidget:
             _, fp, fn, _ = self._cnf_matrix.ravel()
             fp_total = format(fp * costs["fp"], "6,d").replace(",", "{,}")
             fn_total = format(fn * costs["fn"], "6,d").replace(",", "{,}")
+            grand_total = format(
+                (fn * costs["fn"] + fp * costs["fp"]), "6,d"
+            ).replace(",", "{,}")
             s = r"""
                     \begin{align}
                         \text{Wasted admin costs:} &~€ & $FP_TOTAL\\
-                        \text{Wasted legal costs:} &~€ & $FN_TOTAL
+                        \text{Wasted legal costs:} &~€ & $FN_TOTAL \\
+                        \hline \\
+                        \text{Total wasted costs:} &~€ & $GRAND_TOTAL
                     \end{align}
             """
 
-            temp = Template(s).substitute(FP_TOTAL=fp_total, FN_TOTAL=fn_total)
+            temp = Template(s).substitute(
+                FP_TOTAL=fp_total, FN_TOTAL=fn_total, GRAND_TOTAL=grand_total
+            )
             display(Math(temp))
 
     def __cnf_matrix(self, w, font_size=25):
